.. configuration.core.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._configuration._core package.



AutoArchive._configuration._core
================================

.. automodule:: AutoArchive._configuration._core
   :no-members:



Modules
-------

configuration_component
^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core.configuration_component



_app_config
^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core._app_config
.. autoclass:: _AppConfig
   :no-members:
   :members: getArchiveSpecs, _addOrReplaceOption



_cmdline_arguments_processor
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core._cmdline_arguments_processor
.. autoclass:: _CmdlineArgumentsProcessor



_config_file_processor
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core._config_file_processor
.. autoclass:: _ConfigFileProcessor



_file_storage
^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core._file_storage
.. autoclass:: _FileStorage



_storage_portion
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._configuration._core._storage_portion
.. autoclass:: _StoragePortion
